@@ -214,6 +214,11 @@ _prefs_load(void)
         }
     }
 
+    // 0.12 started to remove `sourcepath`
+    if (g_key_file_has_key(prefs, PREF_GROUP_PLUGINS, "sourcepath", NULL)) {
+        g_key_file_remove_key(prefs, PREF_GROUP_PLUGINS, "sourcepath", NULL);
+    }
+
     _save_prefs();
 
     boolean_choice_ac = autocomplete_new();
@@ -897,30 +902,23 @@ prefs_get_occupants_size(void)
     }
 }
 
-char
+char*
 prefs_get_occupants_char(void)
 {
-    char result = 0;
 
-    char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "occupants.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
-    }
-    free(resultstr);
+    char* result = g_key_file_get_string(prefs, PREF_GROUP_UI, "occupants.char", NULL);
 
     return result;
 }
 
 void
-prefs_set_occupants_char(char ch)
+prefs_set_occupants_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "occupants.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "occupants.char", ch);
+    } else {
+        log_error("Could not set roster resource char: %s", ch);
+    }
 }
 
 void
@@ -950,30 +948,22 @@ prefs_set_occupants_indent(gint value)
     g_key_file_set_integer(prefs, PREF_GROUP_UI, "occupants.indent", value);
 }
 
-char
+char*
 prefs_get_occupants_header_char(void)
 {
-    char result = 0;
-
-    char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "occupants.header.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
-    }
-    free(resultstr);
+    char* result = g_key_file_get_string(prefs, PREF_GROUP_UI, "occupants.header.char", NULL);
 
     return result;
 }
 
 void
-prefs_set_occupants_header_char(char ch)
+prefs_set_occupants_header_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "occupants.header.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "occupants.header.char", ch);
+    } else {
+        log_error("Could not set roster resource char: %s", ch);
+    }
 }
 
 void
@@ -1075,30 +1065,27 @@ prefs_set_omemo_char(char* ch)
     return _prefs_set_encryption_char(ch, PREF_GROUP_OMEMO, "omemo.char");
 }
 
-char
+char*
 prefs_get_roster_header_char(void)
 {
-    char result = 0;
+    char* result = NULL;
 
     char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.header.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
+    if (resultstr) {
+        result = resultstr;
     }
-    free(resultstr);
 
     return result;
 }
 
 void
-prefs_set_roster_header_char(char ch)
+prefs_set_roster_header_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.header.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.header.char", ch);
+    } else {
+        log_error("Could not set roster header char: %s", ch);
+    }
 }
 
 void
@@ -1107,30 +1094,22 @@ prefs_clear_roster_header_char(void)
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.header.char", NULL);
 }
 
-char
+char*
 prefs_get_roster_contact_char(void)
 {
-    char result = 0;
-
-    char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.contact.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
-    }
-    free(resultstr);
+    char* result = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.contact.char", NULL);
 
     return result;
 }
 
 void
-prefs_set_roster_contact_char(char ch)
+prefs_set_roster_contact_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.contact.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.contact.char", ch);
+    } else {
+        log_error("Could not set roster contact char: %s", ch);
+    }
 }
 
 void
@@ -1139,30 +1118,22 @@ prefs_clear_roster_contact_char(void)
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.contact.char", NULL);
 }
 
-char
+char*
 prefs_get_roster_resource_char(void)
 {
-    char result = 0;
-
-    char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.resource.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
-    }
-    free(resultstr);
+    char* result = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.resource.char", NULL);
 
     return result;
 }
 
 void
-prefs_set_roster_resource_char(char ch)
+prefs_set_roster_resource_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.resource.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.resource.char", ch);
+    } else {
+        log_error("Could not set roster resource char: %s", ch);
+    }
 }
 
 void
@@ -1171,30 +1142,22 @@ prefs_clear_roster_resource_char(void)
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.resource.char", NULL);
 }
 
-char
+char*
 prefs_get_roster_private_char(void)
 {
-    char result = 0;
-
-    char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.private.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
-    }
-    free(resultstr);
+    char* result = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.private.char", NULL);
 
     return result;
 }
 
 void
-prefs_set_roster_private_char(char ch)
+prefs_set_roster_private_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.private.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.private.char", ch);
+    } else {
+        log_error("Could not set roster resource char: %s", ch);
+    }
 }
 
 void
@@ -1203,30 +1166,22 @@ prefs_clear_roster_private_char(void)
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.private.char", NULL);
 }
 
-char
+char*
 prefs_get_roster_room_char(void)
 {
-    char result = 0;
-
-    char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.rooms.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
-    }
-    free(resultstr);
+    char* result = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.rooms.char", NULL);
 
     return result;
 }
 
 void
-prefs_set_roster_room_char(char ch)
+prefs_set_roster_room_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.rooms.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.rooms.char", ch);
+    } else {
+        log_error("Could not set roster resource char: %s", ch);
+    }
 }
 
 void
@@ -1235,30 +1190,22 @@ prefs_clear_roster_room_char(void)
     g_key_file_remove_key(prefs, PREF_GROUP_UI, "roster.rooms.char", NULL);
 }
 
-char
+char*
 prefs_get_roster_room_private_char(void)
 {
-    char result = 0;
-
-    char* resultstr = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.rooms.private.char", NULL);
-    if (!resultstr) {
-        result = 0;
-    } else {
-        result = resultstr[0];
-    }
-    free(resultstr);
+    char* result = g_key_file_get_string(prefs, PREF_GROUP_UI, "roster.rooms.private.char", NULL);
 
     return result;
 }
 
 void
-prefs_set_roster_room_private_char(char ch)
+prefs_set_roster_room_private_char(char* ch)
 {
-    char str[2];
-    str[0] = ch;
-    str[1] = '\0';
-
-    g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.rooms.private.char", str);
+    if (g_utf8_strlen(ch, 4) == 1) {
+        g_key_file_set_string(prefs, PREF_GROUP_UI, "roster.rooms.private.char", ch);
+    } else {
+        log_error("Could not set roster resource char: %s", ch);
+    }
 }
 
 void
@@ -1928,8 +1875,6 @@ _get_group(preference_t pref)
     case PREF_BOOKMARK_INVITE:
     case PREF_ROOM_LIST_CACHE:
         return PREF_GROUP_MUC;
-    case PREF_PLUGINS_SOURCEPATH:
-        return PREF_GROUP_PLUGINS;
     case PREF_OMEMO_LOG:
     case PREF_OMEMO_POLICY:
     case PREF_OMEMO_TRUST_MODE:
@@ -2163,8 +2108,6 @@ _get_key(preference_t pref)
         return "color.occupants.nick";
     case PREF_BOOKMARK_INVITE:
         return "bookmark.invite";
-    case PREF_PLUGINS_SOURCEPATH:
-        return "sourcepath";
     case PREF_ROOM_LIST_CACHE:
         return "rooms.cache";
     case PREF_STATUSBAR_SHOW_NAME:
@@ -2251,6 +2194,7 @@ _get_default_boolean(preference_t pref)
     case PREF_COLOR_NICK_OWN:
     case PREF_INTYPE:
     case PREF_INTYPE_CONSOLE:
+    case PREF_NOTIFY_MENTION_WHOLE_WORD:
         return TRUE;
     default:
         return FALSE;
@@ -2334,7 +2278,10 @@ _get_default_string(preference_t pref)
     case PREF_URL_OPEN_CMD:
         return "xdg-open %u";
     case PREF_COMPOSE_EDITOR:
-        return "vim";
+    {
+        gchar* editor = getenv("EDITOR");
+        return editor ? editor : "vim";
+    }
     case PREF_URL_SAVE_CMD:
         return NULL; // Default to built-in method.
     default:
