@@ -157,7 +157,6 @@ typedef enum {
     PREF_ROSTER_COLOR_NICK,
     PREF_OCCUPANTS_COLOR_NICK,
     PREF_BOOKMARK_INVITE,
-    PREF_PLUGINS_SOURCEPATH,
     PREF_ROOM_LIST_CACHE,
     PREF_STATUSBAR_SHOW_NAME,
     PREF_STATUSBAR_SHOW_NUMBER,
@@ -255,29 +254,29 @@ gboolean prefs_set_omemo_char(char* ch);
 char* prefs_get_ox_char(void);
 gboolean prefs_set_ox_char(char* ch);
 
-char prefs_get_roster_header_char(void);
-void prefs_set_roster_header_char(char ch);
+char* prefs_get_roster_header_char(void);
+void prefs_set_roster_header_char(char* ch);
 void prefs_clear_roster_header_char(void);
-char prefs_get_roster_contact_char(void);
-void prefs_set_roster_contact_char(char ch);
+char* prefs_get_roster_contact_char(void);
+void prefs_set_roster_contact_char(char* ch);
 void prefs_clear_roster_contact_char(void);
-char prefs_get_roster_resource_char(void);
-void prefs_set_roster_resource_char(char ch);
+char* prefs_get_roster_resource_char(void);
+void prefs_set_roster_resource_char(char* ch);
 void prefs_clear_roster_resource_char(void);
-char prefs_get_roster_private_char(void);
-void prefs_set_roster_private_char(char ch);
+char* prefs_get_roster_private_char(void);
+void prefs_set_roster_private_char(char* ch);
 void prefs_clear_roster_private_char(void);
-char prefs_get_roster_room_char(void);
-void prefs_set_roster_room_char(char ch);
+char* prefs_get_roster_room_char(void);
+void prefs_set_roster_room_char(char* ch);
 void prefs_clear_roster_room_char(void);
-char prefs_get_roster_room_private_char(void);
-void prefs_set_roster_room_private_char(char ch);
+char* prefs_get_roster_room_private_char(void);
+void prefs_set_roster_room_private_char(char* ch);
 void prefs_clear_roster_room_private_char(void);
-char prefs_get_occupants_char(void);
-void prefs_set_occupants_char(char ch);
+char* prefs_get_occupants_char(void);
+void prefs_set_occupants_char(char* ch);
 void prefs_clear_occupants_char(void);
-char prefs_get_occupants_header_char(void);
-void prefs_set_occupants_header_char(char ch);
+char* prefs_get_occupants_header_char(void);
+void prefs_set_occupants_header_char(char* ch);
 void prefs_clear_occupants_header_char(void);
 
 gint prefs_get_roster_contact_indent(void);
