@@ -56,27 +56,7 @@ static prof_msg_type_t _get_message_type_type(const char* const type);
 static char*
 _get_db_filename(ProfAccount* account)
 {
-    gchar* database_dir = files_get_account_data_path(DIR_DATABASE, account->jid);
-
-    int res = g_mkdir_with_parents(database_dir, S_IRWXU);
-    if (res == -1) {
-        const char* errmsg = strerror(errno);
-        if (errmsg) {
-            log_error("DATABASE: error creating directory: %s, %s", database_dir, errmsg);
-        } else {
-            log_error("DATABASE: creating directory: %s", database_dir);
-        }
-        g_free(database_dir);
-        return NULL;
-    }
-
-    GString* chatlog_filename = g_string_new(database_dir);
-    g_string_append(chatlog_filename, "/chatlog.db");
-    gchar* result = g_strdup(chatlog_filename->str);
-    g_string_free(chatlog_filename, TRUE);
-    g_free(database_dir);
-
-    return result;
+    return files_file_in_account_data_path(DIR_DATABASE, account->jid, "chatlog.db");
 }
 
 gboolean
@@ -178,7 +158,7 @@ _log_database_add_outgoing(char* type, const char* const id, const char* const b
     msg->from_jid = jid_create(barejid);
     msg->plain = message ? strdup(message) : NULL;
     msg->replace_id = replace_id ? strdup(replace_id) : NULL;
-    msg->timestamp = g_date_time_new_now_local(); //TODO: get from outside. best to have whole ProfMessage from outside
+    msg->timestamp = g_date_time_new_now_local(); // TODO: get from outside. best to have whole ProfMessage from outside
     msg->enc = enc;
 
     Jid* myjid = jid_create(connection_get_fulljid());
@@ -328,19 +308,19 @@ _add_to_db(ProfMessage* message, char* type, const Jid* const from_jid, const Ji
         type = (char*)_get_message_type_str(message->type);
     }
 
-    query = sqlite3_mprintf("INSERT INTO `ChatLogs` (`from_jid`, `from_resource`, `to_jid`, `to_resource`, `message`, `timestamp`, `stanza_id`, `archive_id`, `replace_id`, `type`, `encryption`) SELECT '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q' WHERE NOT EXISTS (SELECT 1 FROM `ChatLogs` WHERE `archive_id` = '%q')",
-            from_jid->barejid,
-            from_jid->resourcepart ? from_jid->resourcepart : "",
-            to_jid->barejid,
-            to_jid->resourcepart ? to_jid->resourcepart : "",
-            message->plain ? message->plain : "",
-            date_fmt ? date_fmt : "",
-            message->id ? message->id : "",
-            message->stanzaid ? message->stanzaid : "",
-            message->replace_id ? message->replace_id : "",
-            type ? type : "",
-            enc ? enc : "",
-            message->stanzaid ? message->stanzaid : "");
+    query = sqlite3_mprintf("INSERT INTO `ChatLogs` (`from_jid`, `from_resource`, `to_jid`, `to_resource`, `message`, `timestamp`, `stanza_id`, `archive_id`, `replace_id`, `type`, `encryption`) SELECT '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q', '%q' WHERE NOT EXISTS (SELECT 1 FROM `ChatLogs` WHERE `archive_id` = '%q' AND `archive_id` != '')",
+                            from_jid->barejid,
+                            from_jid->resourcepart ? from_jid->resourcepart : "",
+                            to_jid->barejid,
+                            to_jid->resourcepart ? to_jid->resourcepart : "",
+                            message->plain ? message->plain : "",
+                            date_fmt ? date_fmt : "",
+                            message->id ? message->id : "",
+                            message->stanzaid ? message->stanzaid : "",
+                            message->replace_id ? message->replace_id : "",
+                            type ? type : "",
+                            enc ? enc : "",
+                            message->stanzaid ? message->stanzaid : "");
     if (!query) {
         log_error("log_database_add(): SQL query. could not allocate memory");
         return;
