@@ -69,7 +69,7 @@ static char* theme_name = NULL;
 int
 main(int argc, char** argv)
 {
-    if (argc == 2  && g_strcmp0(PACKAGE_STATUS, "development") == 0) {
+    if (argc == 2 && g_strcmp0(PACKAGE_STATUS, "development") == 0) {
         if (g_strcmp0(argv[1], "docgen") == 0) {
             command_docgen();
             return 0;
@@ -125,12 +125,7 @@ main(int argc, char** argv)
 
         g_print("Build information:\n");
 
-#ifdef HAVE_LIBMESODE
-        g_print("XMPP library: libmesode\n");
-#endif
-#ifdef HAVE_LIBSTROPHE
         g_print("XMPP library: libstrophe\n");
-#endif
 
         if (is_notify_enabled()) {
             g_print("Desktop notification support: Enabled\n");
