@@ -84,6 +84,7 @@ static unsigned char* _omemo_fingerprint_decode(const char* const fingerprint, s
 static char* _omemo_unformat_fingerprint(const char* const fingerprint_formatted);
 static void _cache_device_identity(const char* const jid, uint32_t device_id, ec_public_key* identity);
 static void _g_hash_table_free(GHashTable* hash_table);
+static void _acquire_sender_devices_list(void);
 
 typedef gboolean (*OmemoDeviceListHandler)(const char* const jid, GList* device_list);
 
@@ -230,7 +231,11 @@ omemo_on_connect(ProfAccount* account)
     omemo_ctx.device_list_handler = g_hash_table_new_full(g_str_hash, g_str_equal, free, NULL);
     omemo_ctx.known_devices = g_hash_table_new_full(g_str_hash, g_str_equal, free, (GDestroyNotify)_g_hash_table_free);
 
-    gchar* omemo_dir = files_get_account_data_path(DIR_OMEMO, account->jid);
+    gchar* omemo_dir = files_file_in_account_data_path(DIR_OMEMO, account->jid, NULL);
+    if (!omemo_dir) {
+        log_error("[OMEMO] failed creating directory");
+        return;
+    }
 
     omemo_ctx.identity_filename = g_string_new(omemo_dir);
     g_string_append(omemo_ctx.identity_filename, "/identity.txt");
@@ -241,17 +246,6 @@ omemo_on_connect(ProfAccount* account)
     omemo_ctx.known_devices_filename = g_string_new(omemo_dir);
     g_string_append(omemo_ctx.known_devices_filename, "/known_devices.txt");
 
-    errno = 0;
-    int res = g_mkdir_with_parents(omemo_dir, S_IRWXU);
-    if (res == -1) {
-        const char* errmsg = strerror(errno);
-        if (errmsg) {
-            log_error("[OMEMO] error creating directory: %s, %s", omemo_dir, errmsg);
-        } else {
-            log_error("[OMEMO] creating directory: %s", omemo_dir);
-        }
-    }
-
     g_free(omemo_dir);
 
     omemo_devicelist_subscribe();
@@ -384,21 +378,28 @@ omemo_publish_crypto_materials(void)
         return;
     }
 
+    omemo_bundle_publish(true);
+}
+
+static void
+_acquire_sender_devices_list(void)
+{
     char* barejid = connection_get_barejid();
 
-    /* Ensure we get our current device list, and it gets updated with our
-     * device_id */
     g_hash_table_insert(omemo_ctx.device_list_handler, strdup(barejid), _handle_own_device_list);
     omemo_devicelist_request(barejid);
 
-    omemo_bundle_publish(true);
-
     free(barejid);
 }
 
 void
 omemo_start_sessions(void)
 {
+    // before any session may be started, a list on
+    // available sender devices must be acquired
+    log_debug("[OMEMO] Acquiring sender devices list");
+    _acquire_sender_devices_list();
+
     GSList* contacts = roster_get_contacts(ROSTER_ORD_NAME);
     if (contacts) {
         GSList* curr;
@@ -422,7 +423,7 @@ omemo_start_session(const char* const barejid)
             // Own devices are handled by _handle_own_device_list
             // We won't add _handle_device_list_start_session for ourself
             char* mybarejid = connection_get_barejid();
-            if( g_strcmp0(mybarejid, barejid ) != 0 ) {
+            if (g_strcmp0(mybarejid, barejid) != 0) {
                 g_hash_table_insert(omemo_ctx.device_list_handler, strdup(barejid), _handle_device_list_start_session);
             }
             free(mybarejid);
@@ -681,12 +682,12 @@ omemo_start_device_session(const char* const jid, uint32_t device_id,
     }
 
     if (!trusted) {
-        log_debug("[OMEMO] We don't trust device %d for %s\n", device_id,jid);
+        log_debug("[OMEMO] We don't trust device %d for %s\n", device_id, jid);
         goto out;
     }
 
     if (!contains_session(&address, omemo_ctx.session_store)) {
-        log_debug("[OMEMO] There is no Session for %s ( %d) ,... building session.", address.name, address.device_id );
+        log_debug("[OMEMO] There is no Session for %s ( %d) ,... building session.", address.name, address.device_id);
         int res;
         session_pre_key_bundle* bundle;
         signal_protocol_address* address;
@@ -815,7 +816,7 @@ omemo_on_message_send(ProfWin* win, const char* const message, gboolean request_
             // <https://xmpp.org/extensions/xep-0384.html#encrypt>).
             // Yourself as recipients in case of MUC
             char* mybarejid = connection_get_barejid();
-            if ( !g_strcmp0(mybarejid, recipients_iter->data) ) {
+            if (!g_strcmp0(mybarejid, recipients_iter->data)) {
                 if (GPOINTER_TO_INT(device_ids_iter->data) == omemo_ctx.device_id) {
                     free(mybarejid);
                     log_debug("[OMEMO][SEND] Skipping %d (my device) ", GPOINTER_TO_INT(device_ids_iter->data));
@@ -826,15 +827,15 @@ omemo_on_message_send(ProfWin* win, const char* const message, gboolean request_
 
             log_debug("[OMEMO][SEND] recipients with device id %d for %s", GPOINTER_TO_INT(device_ids_iter->data), recipients_iter->data);
             res = session_cipher_create(&cipher, omemo_ctx.store, &address, omemo_ctx.signal);
-            if (res != SG_SUCCESS ) {
+            if (res != SG_SUCCESS) {
                 log_error("[OMEMO][SEND] cannot create cipher for %s device id %d - code: %d", address.name, address.device_id, res);
                 continue;
             }
 
             res = session_cipher_encrypt(cipher, key_tag, AES128_GCM_KEY_LENGTH + AES128_GCM_TAG_LENGTH, &ciphertext);
             session_cipher_free(cipher);
-            if (res != SG_SUCCESS ) {
-                log_info("[OMEMO][SEND] cannot encrypt key for %s device id %d - code: %d", address.name, address.device_id,res);
+            if (res != SG_SUCCESS) {
+                log_info("[OMEMO][SEND] cannot encrypt key for %s device id %d - code: %d", address.name, address.device_id, res);
                 continue;
             }
             signal_buffer* buffer = ciphertext_message_get_serialized(ciphertext);
@@ -855,9 +856,9 @@ omemo_on_message_send(ProfWin* win, const char* const message, gboolean request_
     // (Since none of the recipients would be able to read the message.)
     if (keys == NULL) {
         win_println(win, THEME_ERROR, "!", "This message cannot be decrypted for any recipient.\n"
-                "You should trust your recipients' device fingerprint(s) using \"/omemo fingerprint trust FINGERPRINT\".\n"
-                "It could also be that the key bundle of the recipient(s) have not been received. "
-                "In this case, you could try \"omemo end\", \"omemo start\", and send the message again.");
+                                           "You should trust your recipients' device fingerprint(s) using \"/omemo fingerprint trust FINGERPRINT\".\n"
+                                           "It could also be that the key bundle of the recipient(s) have not been received. "
+                                           "In this case, you could try \"omemo end\", \"omemo start\", and send the message again.");
         goto out;
     }
 
