@@ -161,27 +161,13 @@ p_gpg_close(void)
 void
 p_gpg_on_connect(const char* const barejid)
 {
-    gchar* pubsfile = files_get_account_data_path(DIR_PGP, barejid);
-
-    // mkdir if doesn't exist for account
-    errno = 0;
-    int res = g_mkdir_with_parents(pubsfile, S_IRWXU);
-    if (res == -1) {
-        const char* errmsg = strerror(errno);
-        if (errmsg) {
-            log_error("Error creating directory: %s, %s", pubsfile, errmsg);
-        } else {
-            log_error("Error creating directory: %s", pubsfile);
-        }
+    pubsloc = files_file_in_account_data_path(DIR_PGP, barejid, "pubkeys");
+    if (!pubsloc) {
+        log_error("Could not create directory for account %s.", barejid);
+        cons_show_error("Could not create directory for account %s.", barejid);
+        return;
     }
 
-    // create or read publickeys
-    GString* pubtmp = g_string_new(pubsfile);
-    g_string_append(pubtmp, "/pubkeys");
-    pubsloc = pubtmp->str;
-    g_string_free(pubtmp, FALSE);
-    g_free(pubsfile);
-
     if (g_file_test(pubsloc, G_FILE_TEST_EXISTS)) {
         g_chmod(pubsloc, S_IRUSR | S_IWUSR);
     }
@@ -806,7 +792,7 @@ ox_gpg_public_keys(void)
     error = gpgme_new(&ctx);
 
     if (error) {
-        log_error("OX - gpgme_new failed: %s %s", gpgme_strsource(error), gpgme_strerror(error));
+        log_error("OX: Failed to create gpgme context. %s %s", gpgme_strsource(error), gpgme_strerror(error));
         return NULL;
     }
 
@@ -871,15 +857,15 @@ ox_gpg_public_keys(void)
     }
     gpgme_release(ctx);
 
-    //autocomplete_clear(key_ac);
-    //    GList *ids = g_hash_table_get_keys(result);
-    //    GList *curr = ids;
-    //    while (curr) {
-    //        ProfPGPKey *key = g_hash_table_lookup(result, curr->data);
-    //        autocomplete_add(key_ac, key->id);
-    //        curr = curr->next;
-    //    }
-    //    g_list_free(ids);
+    // autocomplete_clear(key_ac);
+    //     GList *ids = g_hash_table_get_keys(result);
+    //     GList *curr = ids;
+    //     while (curr) {
+    //         ProfPGPKey *key = g_hash_table_lookup(result, curr->data);
+    //         autocomplete_add(key_ac, key->id);
+    //         curr = curr->next;
+    //     }
+    //     g_list_free(ids);
 
     return result;
 }
@@ -894,13 +880,13 @@ p_ox_gpg_signcrypt(const char* const sender_barejid, const char* const recipient
 
     gpgme_error_t error = gpgme_new(&ctx);
     if (GPG_ERR_NO_ERROR != error) {
-        printf("gpgme_new: %d\n", error);
+        log_error("OX: Failed to create gpgme context. %s %s", gpgme_strsource(error), gpgme_strerror(error));
         return NULL;
     }
 
     error = gpgme_set_protocol(ctx, GPGME_PROTOCOL_OPENPGP);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: Signcrypt error: %s", gpgme_strerror(error));
     }
 
     gpgme_set_armor(ctx, 0);
@@ -908,7 +894,7 @@ p_ox_gpg_signcrypt(const char* const sender_barejid, const char* const recipient
     gpgme_set_offline(ctx, 1);
     gpgme_set_keylist_mode(ctx, GPGME_KEYLIST_MODE_LOCAL);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: Signcrypt error: %s", gpgme_strerror(error));
     }
 
     gpgme_key_t recp[3];
@@ -928,22 +914,23 @@ p_ox_gpg_signcrypt(const char* const sender_barejid, const char* const recipient
     // lookup own key
     recp[0] = _ox_key_lookup(sender_barejid, TRUE);
     if (error != 0) {
-        log_error("Key not found for %s. GpgME Error: %s", xmpp_jid_me, gpgme_strerror(error));
+        log_error("OX: Key not found for %s. Error: %s", xmpp_jid_me, gpgme_strerror(error));
         return NULL;
     }
 
     error = gpgme_signers_add(ctx, recp[0]);
     if (error != 0) {
-        log_error("gpgme_signers_add %s. GpgME Error: %s", xmpp_jid_me, gpgme_strerror(error));
+        log_error("OX: gpgme_signers_add %s. Error: %s", xmpp_jid_me, gpgme_strerror(error));
         return NULL;
     }
 
     // lookup key of recipient
     recp[1] = _ox_key_lookup(recipient_barejid, FALSE);
     if (error != 0) {
-        log_error("Key not found for %s. GpgME Error: %s", xmpp_jid_recipient, gpgme_strerror(error));
+        log_error("OX: Key not found for %s. Error: %s", xmpp_jid_recipient, gpgme_strerror(error));
         return NULL;
     }
+
     recp[2] = NULL;
     log_debug("%s <%s>", recp[0]->uids->name, recp[0]->uids->email);
     log_debug("%s <%s>", recp[1]->uids->name, recp[1]->uids->email);
@@ -955,24 +942,24 @@ p_ox_gpg_signcrypt(const char* const sender_barejid, const char* const recipient
 
     error = gpgme_data_new(&plain);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: %s", gpgme_strerror(error));
         return NULL;
     }
 
     error = gpgme_data_new_from_mem(&plain, message, strlen(message), 0);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: %s", gpgme_strerror(error));
         return NULL;
     }
     error = gpgme_data_new(&cipher);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: %s", gpgme_strerror(error));
         return NULL;
     }
 
     error = gpgme_op_encrypt_sign(ctx, recp, flags, plain, cipher);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: %s", gpgme_strerror(error));
         return NULL;
     }
 
@@ -1072,7 +1059,7 @@ static gpgme_key_t
 _ox_key_lookup(const char* const barejid, gboolean secret_only)
 {
     g_assert(barejid);
-    log_debug("Looking for %s key: %s", secret_only == TRUE ? "Private" : "Public", barejid);
+    log_debug("OX: Looking for %s key: %s", secret_only == TRUE ? "Private" : "Public", barejid);
     gpgme_key_t key = NULL;
     gpgme_error_t error;
 
@@ -1080,7 +1067,7 @@ _ox_key_lookup(const char* const barejid, gboolean secret_only)
     error = gpgme_new(&ctx);
 
     if (error) {
-        log_error("OX - gpgme_new failed: %s %s", gpgme_strsource(error), gpgme_strerror(error));
+        log_error("OX: gpgme_new failed: %s %s", gpgme_strsource(error), gpgme_strerror(error));
         return NULL;
     }
 
@@ -1132,8 +1119,6 @@ _ox_key_is_usable(gpgme_key_t key, const char* const barejid, gboolean secret)
 /*!
  * @brief XMPP-OX: Decrypt OX Message.
  *
- *
- *
  * @param base64  base64_encode OpenPGP message.
  *
  * @result decrypt XMPP OX Message NULL terminated C-String
@@ -1143,7 +1128,7 @@ p_ox_gpg_decrypt(char* base64)
 {
     // if there is no private key avaibale,
     // we don't try do decrypt
-    if(!ox_is_private_key_available(connection_get_barejid())) {
+    if (!ox_is_private_key_available(connection_get_barejid())) {
         return NULL;
     }
     setlocale(LC_ALL, "");
@@ -1153,13 +1138,13 @@ p_ox_gpg_decrypt(char* base64)
     gpgme_error_t error = gpgme_new(&ctx);
 
     if (GPG_ERR_NO_ERROR != error) {
-        printf("gpgme_new: %d\n", error);
+        log_error("OX: gpgme_new failed: %s %s", gpgme_strsource(error), gpgme_strerror(error));
         return NULL;
     }
 
     error = gpgme_set_protocol(ctx, GPGME_PROTOCOL_OPENPGP);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: %s", gpgme_strerror(error));
     }
 
     gpgme_set_armor(ctx, 0);
@@ -1167,7 +1152,7 @@ p_ox_gpg_decrypt(char* base64)
     gpgme_set_offline(ctx, 1);
     gpgme_set_keylist_mode(ctx, GPGME_KEYLIST_MODE_LOCAL);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: %s", gpgme_strerror(error));
     }
 
     gpgme_data_t plain = NULL;
@@ -1177,19 +1162,19 @@ p_ox_gpg_decrypt(char* base64)
     guchar* encrypted = g_base64_decode(base64, &s);
     error = gpgme_data_new_from_mem(&cipher, (char*)encrypted, s, 0);
     if (error != 0) {
-        log_error("GpgME Error gpgme_data_new_from_mem: %s", gpgme_strerror(error));
+        log_error("OX: gpgme_data_new_from_mem: %s", gpgme_strerror(error));
         return NULL;
     }
 
     error = gpgme_data_new(&plain);
     if (error != 0) {
-        log_error("GpgME Error: %s", gpgme_strerror(error));
+        log_error("OX: %s", gpgme_strerror(error));
         return NULL;
     }
 
     error = gpgme_op_decrypt_verify(ctx, cipher, plain);
     if (error != 0) {
-        log_error("GpgME Error gpgme_op_decrypt: %s", gpgme_strerror(error));
+        log_error("OX: gpgme_op_decrypt: %s", gpgme_strerror(error));
         error = gpgme_op_decrypt(ctx, cipher, plain);
         if (error != 0) {
             return NULL;
@@ -1210,14 +1195,14 @@ p_ox_gpg_decrypt(char* base64)
  *
  * This function is used to read a key and push it on PEP. There are some checks
  * in this function:
- * 
+ *
  * Key is not
- * - gkey->revoked 
- * - gkey->expired 
+ * - gkey->revoked
+ * - gkey->expired
  * - gkey->disabled
- * - gkey->invalid 
+ * - gkey->invalid
  * - gkey->secret
- * 
+ *
  * Only one key in the file.
  *
  * \param filename filename to read the file.
@@ -1225,12 +1210,10 @@ p_ox_gpg_decrypt(char* base64)
  * \param fp result with the fingerprint or NULL
  *
  */
-
 void
 p_ox_gpg_readkey(const char* const filename, char** key, char** fp)
 {
-
-    log_info("Read OpenPGP Key from file %s", filename);
+    log_info("PX: Read OpenPGP Key from file %s", filename);
 
     GError* error = NULL;
     gchar* data = NULL;
@@ -1248,13 +1231,13 @@ p_ox_gpg_readkey(const char* const filename, char** key, char** fp)
         gpgme_error_t error = gpgme_new(&ctx);
 
         if (GPG_ERR_NO_ERROR != error) {
-            log_error("Read OpenPGP key from file: gpgme_new failed: %s", gpgme_strerror(error));
+            log_error("OX: Read OpenPGP key from file: gpgme_new failed: %s", gpgme_strerror(error));
             return;
         }
 
         error = gpgme_set_protocol(ctx, GPGME_PROTOCOL_OPENPGP);
         if (error != GPG_ERR_NO_ERROR) {
-            log_error("Read OpenPGP key from file: set GPGME_PROTOCOL_OPENPGP:  %s", gpgme_strerror(error));
+            log_error("OX: Read OpenPGP key from file: set GPGME_PROTOCOL_OPENPGP:  %s", gpgme_strerror(error));
             return;
         }
 
@@ -1266,36 +1249,36 @@ p_ox_gpg_readkey(const char* const filename, char** key, char** fp)
         gpgme_data_t gpgme_data = NULL;
         error = gpgme_data_new(&gpgme_data);
         if (error != GPG_ERR_NO_ERROR) {
-            log_error("Read OpenPGP key from file: gpgme_data_new %s", gpgme_strerror(error));
+            log_error("OX: Read OpenPGP key from file: gpgme_data_new %s", gpgme_strerror(error));
             return;
         }
 
         error = gpgme_data_new_from_mem(&gpgme_data, (char*)data, size, 0);
         if (error != GPG_ERR_NO_ERROR) {
-            log_error("Read OpenPGP key from file: gpgme_data_new_from_mem %s", gpgme_strerror(error));
+            log_error("OX: Read OpenPGP key from file: gpgme_data_new_from_mem %s", gpgme_strerror(error));
             return;
         }
         error = gpgme_op_keylist_from_data_start(ctx, gpgme_data, 0);
         if (error != GPG_ERR_NO_ERROR) {
-            log_error("Read OpenPGP key from file: gpgme_op_keylist_from_data_start %s", gpgme_strerror(error));
+            log_error("OX: Read OpenPGP key from file: gpgme_op_keylist_from_data_start %s", gpgme_strerror(error));
             return;
         }
         gpgme_key_t gkey;
         error = gpgme_op_keylist_next(ctx, &gkey);
         if (error != GPG_ERR_NO_ERROR) {
-            log_error("Read OpenPGP key from file: gpgme_op_keylist_next %s", gpgme_strerror(error));
+            log_error("OX: Read OpenPGP key from file: gpgme_op_keylist_next %s", gpgme_strerror(error));
             return;
         }
 
         gpgme_key_t end;
         error = gpgme_op_keylist_next(ctx, &end);
         if (error == GPG_ERR_NO_ERROR) {
-            log_error("Read OpenPGP key from file: ambiguous key");
+            log_error("OX: Read OpenPGP key from file: ambiguous key");
             return;
         }
 
         if (gkey->revoked || gkey->expired || gkey->disabled || gkey->invalid || gkey->secret) {
-            log_error("Read OpenPGP key from file: Key is not valid");
+            log_error("OX: Read OpenPGP key from file: Key is not valid");
             return;
         }
 
@@ -1304,7 +1287,7 @@ p_ox_gpg_readkey(const char* const filename, char** key, char** fp)
         *key = strdup(keybase64);
         *fp = strdup(gkey->fpr);
     } else {
-        log_error("Read OpenPGP key from file: Unable to read file: %s", error->message);
+        log_error("OX: Read OpenPGP key from file: Unable to read file: %s", error->message);
     }
 }
 
@@ -1321,13 +1304,13 @@ p_ox_gpg_import(char* base64_public_key)
     gpgme_error_t error = gpgme_new(&ctx);
 
     if (GPG_ERR_NO_ERROR != error) {
-        log_error("Read OpenPGP key from file: gpgme_new failed: %s", gpgme_strerror(error));
+        log_error("OX: Read OpenPGP key from file: gpgme_new failed: %s", gpgme_strerror(error));
         return FALSE;
     }
 
     error = gpgme_set_protocol(ctx, GPGME_PROTOCOL_OPENPGP);
     if (error != GPG_ERR_NO_ERROR) {
-        log_error("Read OpenPGP key from file: set GPGME_PROTOCOL_OPENPGP:  %s", gpgme_strerror(error));
+        log_error("OX: Read OpenPGP key from file: set GPGME_PROTOCOL_OPENPGP:  %s", gpgme_strerror(error));
         return FALSE;
     }
 
@@ -1339,14 +1322,14 @@ p_ox_gpg_import(char* base64_public_key)
     gpgme_data_t gpgme_data = NULL;
     error = gpgme_data_new(&gpgme_data);
     if (error != GPG_ERR_NO_ERROR) {
-        log_error("Read OpenPGP key from file: gpgme_data_new %s", gpgme_strerror(error));
+        log_error("OX: Read OpenPGP key from file: gpgme_data_new %s", gpgme_strerror(error));
         return FALSE;
     }
 
     gpgme_data_new_from_mem(&gpgme_data, (gchar*)key, size, 0);
     error = gpgme_op_import(ctx, gpgme_data);
     if (error != GPG_ERR_NO_ERROR) {
-        log_error("Failed to import key");
+        log_error("OX: Failed to import key");
     }
 
     return TRUE;
