@@ -181,7 +181,7 @@ cons_show_error(const char* const msg, ...)
 }
 
 void
-cons_show_tlscert_summary(TLSCertificate* cert)
+cons_show_tlscert_summary(const TLSCertificate* cert)
 {
     if (!cert) {
         return;
@@ -193,7 +193,7 @@ cons_show_tlscert_summary(TLSCertificate* cert)
 }
 
 void
-cons_show_tlscert(TLSCertificate* cert)
+cons_show_tlscert(const TLSCertificate* cert)
 {
     if (!cert) {
         return;
@@ -507,7 +507,8 @@ cons_show_wins(gboolean unread)
 }
 
 void
-cons_show_wins_attention() {
+cons_show_wins_attention()
+{
     ProfWin* console = wins_get_console();
     cons_show("");
     GSList* window_strings = wins_create_summary_attention();
@@ -837,12 +838,14 @@ cons_show_disco_items(GSList* items, const char* const jid)
     cons_alert(NULL);
 }
 
-static void _cons_print_contact_information_item(gpointer data, gpointer user_data)
+static void
+_cons_print_contact_information_item(gpointer data, gpointer user_data)
 {
     cons_show("    %s", (char*)data);
 }
 
-static void _cons_print_contact_information_hashlist_item(gpointer key, gpointer value, gpointer userdata)
+static void
+_cons_print_contact_information_hashlist_item(gpointer key, gpointer value, gpointer userdata)
 {
     cons_show("  %s:", (char*)key);
     g_slist_foreach((GSList*)value, _cons_print_contact_information_item, NULL);
@@ -1337,11 +1340,13 @@ cons_occupants_setting(void)
     else
         cons_show("Occupants wrap (/occupants)         : OFF");
 
-    char occupants_ch = prefs_get_occupants_char();
-    if (occupants_ch)
-        cons_show("Occupants char (/occupants)         : %c", occupants_ch);
-    else
+    char* occupants_ch = prefs_get_occupants_char();
+    if (occupants_ch) {
+        cons_show("Occupants char (/occupants)         : %s", occupants_ch);
+        free(occupants_ch);
+    } else {
         cons_show("Occupants char (/occupants)         : none");
+    }
 
     gint occupant_indent = prefs_get_occupants_indent();
     cons_show("Occupant indent (/occupants)        : %d", occupant_indent);
@@ -1349,11 +1354,13 @@ cons_occupants_setting(void)
     int size = prefs_get_occupants_size();
     cons_show("Occupants size (/occupants)         : %d", size);
 
-    char header_ch = prefs_get_occupants_header_char();
-    if (header_ch)
-        cons_show("Occupants header char (/occupants)  : %c", header_ch);
-    else
+    char* header_ch = prefs_get_occupants_header_char();
+    if (header_ch) {
+        cons_show("Occupants header char (/occupants)  : %s", header_ch);
+        free(header_ch);
+    } else {
         cons_show("Occupants header char (/occupants)  : none");
+    }
 }
 
 void
@@ -1472,41 +1479,53 @@ cons_roster_setting(void)
     else
         cons_show("Roster offline (/roster)            : hide");
 
-    char header_ch = prefs_get_roster_header_char();
-    if (header_ch)
-        cons_show("Roster header char (/roster)        : %c", header_ch);
-    else
+    char* header_ch = prefs_get_roster_header_char();
+    if (header_ch) {
+        cons_show("Roster header char (/roster)        : %s", header_ch);
+        free(header_ch);
+    } else {
         cons_show("Roster header char (/roster)        : none");
+    }
 
-    char contact_ch = prefs_get_roster_contact_char();
-    if (contact_ch)
-        cons_show("Roster contact char (/roster)       : %c", contact_ch);
-    else
+    char* contact_ch = prefs_get_roster_contact_char();
+    if (contact_ch) {
+        cons_show("Roster contact char (/roster)       : %s", contact_ch);
+        free(contact_ch);
+    } else {
         cons_show("Roster contact char (/roster)       : none");
+    }
 
-    char resource_ch = prefs_get_roster_resource_char();
-    if (resource_ch)
-        cons_show("Roster resource char (/roster)      : %c", resource_ch);
-    else
+    char* resource_ch = prefs_get_roster_resource_char();
+    if (resource_ch) {
+        cons_show("Roster resource char (/roster)      : %s", resource_ch);
+        free(resource_ch);
+    } else {
         cons_show("Roster resource char (/roster)      : none");
+    }
 
-    char room_ch = prefs_get_roster_room_char();
-    if (room_ch)
-        cons_show("Roster room char (/roster)          : %c", room_ch);
-    else
+    char* room_ch = prefs_get_roster_room_char();
+    if (room_ch) {
+        cons_show("Roster room char (/roster)          : %s", room_ch);
+        free(room_ch);
+    } else {
         cons_show("Roster room char (/roster)          : none");
+    }
 
-    char room_priv_ch = prefs_get_roster_room_private_char();
-    if (room_priv_ch)
-        cons_show("Roster room private char (/roster)  : %c", room_priv_ch);
-    else
+    char* room_priv_ch = prefs_get_roster_room_private_char();
+    if (room_priv_ch) {
+        cons_show("Roster room private char (/roster)  : %s", room_priv_ch);
+        free(room_priv_ch);
+    } else {
         cons_show("Roster room private char (/roster)  : none");
+    }
 
-    char private_ch = prefs_get_roster_private_char();
-    if (private_ch)
-        cons_show("Roster private char (/roster)       : %c", private_ch);
-    else
+    char* private_ch = prefs_get_roster_private_char();
+    if (private_ch) {
+        cons_show("Roster private char (/roster)       : %s", private_ch);
+        free(private_ch);
+    } else {
         cons_show("Roster private char (/roster)       : none");
+    }
 
     gint contact_indent = prefs_get_roster_contact_indent();
     cons_show("Roster contact indent (/roster)     : %d", contact_indent);
@@ -2140,8 +2159,8 @@ cons_executable_setting(void)
     cons_show("Default '/avatar open' command (/executable avatar)                      : %s", avatar);
     g_free(avatar);
 
-    //TODO: there needs to be a way to get all the "locales"/schemes so we can
-    //display the default openers for all filetypes
+    // TODO: there needs to be a way to get all the "locales"/schemes so we can
+    // display the default openers for all filetypes
     gchar* urlopen = prefs_get_string(PREF_URL_OPEN_CMD);
     cons_show("Default '/url open' command (/executable urlopen)                        : %s", urlopen);
     g_free(urlopen);
