@@ -391,7 +391,7 @@ _mucwin_print_mention(ProfWin* window, const char* const message, const char* co
     while (curr) {
         pos = GPOINTER_TO_INT(curr->data);
 
-        char *before_str = g_utf8_substring(message, last_pos, pos);
+        char* before_str = g_utf8_substring(message, last_pos, pos);
 
         if (last_pos == 0 && strncmp(before_str, "/me ", 4) == 0) {
             win_print_them(window, THEME_ROOMMENTION, ch, flags, "");
@@ -541,6 +541,8 @@ mucwin_outgoing_msg(ProfMucWin* mucwin, const char* const message, const char* c
     if (id) {
         _mucwin_set_last_message(mucwin, id, message);
     }
+
+    wins_add_quotes_ac(window, message);
 }
 
 void
@@ -576,6 +578,7 @@ mucwin_incoming_msg(ProfMucWin* mucwin, const ProfMessage* const message, GSList
 
     win_insert_last_read_position_marker((ProfWin*)mucwin, mucwin->roomjid);
     wins_add_urls_ac(window, message);
+    wins_add_quotes_ac(window, message->plain);
 
     if (g_slist_length(mentions) > 0) {
         _mucwin_print_mention(window, message->plain, message->from_jid->resourcepart, mynick, mentions, ch, flags);
@@ -720,6 +723,9 @@ mucwin_show_affiliation_list(ProfMucWin* mucwin, muc_affiliation_t affiliation)
         case MUC_AFFILIATION_OUTCAST:
             win_println(window, THEME_DEFAULT, "!", "No outcasts found.");
             break;
+        case MUC_AFFILIATION_NONE:
+            win_println(window, THEME_DEFAULT, "!", "No nones found.");
+            break;
         default:
             break;
         }
@@ -738,6 +744,9 @@ mucwin_show_affiliation_list(ProfMucWin* mucwin, muc_affiliation_t affiliation)
         case MUC_AFFILIATION_OUTCAST:
             win_println(window, THEME_DEFAULT, "!", "Outcasts:");
             break;
+        case MUC_AFFILIATION_NONE:
+            win_println(window, THEME_DEFAULT, "!", "Nones:");
+            break;
         default:
             break;
         }
