@@ -76,7 +76,7 @@ int ui_close_read_wins(void);
 void ui_close_win(int index);
 int ui_win_unread(int index);
 gboolean ui_win_has_attention(int index);
-gboolean win_has_attention(ProfWin* window); 
+gboolean win_has_attention(ProfWin* window);
 gboolean win_toggle_attention(ProfWin* window);
 char* ui_ask_password(gboolean confirm);
 char* ui_get_line(void);
@@ -333,8 +333,8 @@ void cons_show_contact_online(PContact contact, Resource* resource, GDateTime* l
 void cons_show_contact_offline(PContact contact, char* resource, char* status);
 void cons_theme_properties(void);
 void cons_theme_colours(void);
-void cons_show_tlscert(TLSCertificate* cert);
-void cons_show_tlscert_summary(TLSCertificate* cert);
+void cons_show_tlscert(const TLSCertificate* cert);
+void cons_show_tlscert_summary(const TLSCertificate* cert);
 
 void cons_alert(ProfWin* alert_origin_window);
 void cons_remove_alert(ProfWin* window);
@@ -398,6 +398,7 @@ void win_command_exec_error(ProfWin* window, const char* const command, const ch
 void win_handle_command_list(ProfWin* window, GSList* cmds);
 void win_handle_command_exec_status(ProfWin* window, const char* const type, const char* const value);
 void win_handle_command_exec_result_note(ProfWin* window, const char* const type, const char* const value);
+char* win_get_last_sent_message(ProfWin* window);
 
 // desktop notifications
 void notifier_initialise(void);
