@@ -43,13 +43,7 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#ifdef HAVE_LIBMESODE
-#include <mesode.h>
-#endif
-
-#ifdef HAVE_LIBSTROPHE
 #include <strophe.h>
-#endif
 
 #include "common.h"
 #include "log.h"
@@ -58,12 +52,12 @@
 #include "event/server_events.h"
 #include "xmpp/connection.h"
 #include "xmpp/session.h"
+#include "xmpp/stanza.h"
 #include "xmpp/iq.h"
 #include "ui/ui.h"
 
 typedef struct prof_conn_t
 {
-    xmpp_log_t* xmpp_log;
     xmpp_ctx_t* xmpp_ctx;
     xmpp_conn_t* xmpp_conn;
     gboolean xmpp_in_event_loop;
@@ -77,31 +71,61 @@ typedef struct prof_conn_t
     GHashTable* requested_features;
 } ProfConnection;
 
+typedef struct
+{
+    const char* username;
+    const char* password;
+} prof_reg_t;
+
 static ProfConnection conn;
 static gchar* profanity_instance_id = NULL;
 static gchar* prof_identifier = NULL;
 
-static xmpp_log_t* _xmpp_get_file_logger(void);
 static void _xmpp_file_logger(void* const userdata, const xmpp_log_level_t level, const char* const area, const char* const msg);
 
 static void _connection_handler(xmpp_conn_t* const xmpp_conn, const xmpp_conn_event_t status, const int error,
                                 xmpp_stream_error_t* const stream_error, void* const userdata);
 
-#ifdef HAVE_LIBMESODE
-TLSCertificate* _xmppcert_to_profcert(xmpp_tlscert_t* xmpptlscert);
-static int _connection_certfail_cb(xmpp_tlscert_t* xmpptlscert, const char* const errormsg);
-#endif
+static TLSCertificate* _xmppcert_to_profcert(const xmpp_tlscert_t* xmpptlscert);
+static int _connection_certfail_cb(const xmpp_tlscert_t* xmpptlscert, const char* errormsg);
 
 static void _random_bytes_init(void);
 static void _random_bytes_close(void);
 static void _compute_identifier(const char* barejid);
 
+static void*
+_xmalloc(size_t size, void* userdata)
+{
+    void* ret = malloc(size);
+    assert(ret != NULL);
+    return ret;
+}
+
+static void
+_xfree(void* p, void* userdata)
+{
+    free(p);
+}
+
+static void*
+_xrealloc(void* p, size_t size, void* userdata)
+{
+    void* ret = realloc(p, size);
+    assert(ret != NULL);
+    return ret;
+}
+
+static xmpp_mem_t prof_mem = {
+    _xmalloc, _xfree, _xrealloc, NULL
+};
+static xmpp_log_t prof_log = {
+    _xmpp_file_logger, NULL
+};
+
 void
 connection_init(void)
 {
     xmpp_initialize();
-    conn.xmpp_conn = NULL;
-    conn.xmpp_ctx = NULL;
     conn.xmpp_in_event_loop = FALSE;
     conn.conn_status = JABBER_DISCONNECTED;
     conn.conn_last_event = XMPP_CONN_DISCONNECT;
@@ -111,6 +135,9 @@ connection_init(void)
     conn.available_resources = g_hash_table_new_full(g_str_hash, g_str_equal, free, (GDestroyNotify)resource_destroy);
     conn.requested_features = g_hash_table_new_full(g_str_hash, g_str_equal, free, NULL);
 
+    conn.xmpp_ctx = xmpp_ctx_new(&prof_mem, &prof_log);
+    conn.xmpp_conn = xmpp_conn_new(conn.xmpp_ctx);
+
     _random_bytes_init();
 }
 
@@ -126,60 +153,38 @@ void
 connection_shutdown(void)
 {
     connection_clear_data();
+    if (conn.xmpp_conn) {
+        xmpp_conn_release(conn.xmpp_conn);
+        conn.xmpp_conn = NULL;
+    }
+    if (conn.xmpp_ctx) {
+        xmpp_ctx_free(conn.xmpp_ctx);
+        conn.xmpp_ctx = NULL;
+    }
     xmpp_shutdown();
 
-    free(conn.xmpp_log);
-    conn.xmpp_log = NULL;
-
     _random_bytes_close();
 }
 
-jabber_conn_status_t
-connection_connect(const char* const jid, const char* const passwd, const char* const altdomain, int port,
-                   const char* const tls_policy, const char* const auth_policy)
+static gboolean
+_conn_apply_settings(const char* const jid, const char* const passwd, const char* const tls_policy, const char* const auth_policy)
 {
-    long flags;
-
-    assert(jid != NULL);
-    assert(passwd != NULL);
-
     Jid* jidp = jid_create(jid);
     if (jidp == NULL) {
         log_error("Malformed JID not able to connect: %s", jid);
         conn.conn_status = JABBER_DISCONNECTED;
-        return conn.conn_status;
+        return FALSE;
     }
 
     _compute_identifier(jidp->barejid);
     jid_destroy(jidp);
 
-    log_info("Connecting as %s", jid);
-
-    if (conn.xmpp_log) {
-        free(conn.xmpp_log);
-    }
-    conn.xmpp_log = _xmpp_get_file_logger();
-
-    if (conn.xmpp_conn) {
-        xmpp_conn_release(conn.xmpp_conn);
-    }
-    if (conn.xmpp_ctx) {
-        xmpp_ctx_free(conn.xmpp_ctx);
-    }
-    conn.xmpp_ctx = xmpp_ctx_new(NULL, conn.xmpp_log);
-    if (conn.xmpp_ctx == NULL) {
-        log_warning("Failed to get libstrophe ctx during connect");
-        return JABBER_DISCONNECTED;
-    }
-    conn.xmpp_conn = xmpp_conn_new(conn.xmpp_ctx);
-    if (conn.xmpp_conn == NULL) {
-        log_warning("Failed to get libstrophe conn during connect");
-        return JABBER_DISCONNECTED;
-    }
+    xmpp_ctx_set_verbosity(conn.xmpp_ctx, 0);
     xmpp_conn_set_jid(conn.xmpp_conn, jid);
-    xmpp_conn_set_pass(conn.xmpp_conn, passwd);
+    if (passwd)
+        xmpp_conn_set_pass(conn.xmpp_conn, passwd);
 
-    flags = xmpp_conn_get_flags(conn.xmpp_conn);
+    long flags = xmpp_conn_get_flags(conn.xmpp_conn);
 
     if (!tls_policy || (g_strcmp0(tls_policy, "force") == 0)) {
         flags |= XMPP_CONN_FLAG_MANDATORY_TLS;
@@ -213,28 +218,33 @@ connection_connect(const char* const jid, const char* const passwd, const char*
 #undef LOG_FLAG_IF_SET
     }
 
-#ifdef HAVE_LIBMESODE
     char* cert_path = prefs_get_tls_certpath();
     if (cert_path) {
-        xmpp_conn_tlscert_path(conn.xmpp_conn, cert_path);
+        xmpp_conn_set_capath(conn.xmpp_conn, cert_path);
         free(cert_path);
     }
 
-    int connect_status = xmpp_connect_client(
-        conn.xmpp_conn,
-        altdomain,
-        port,
-        _connection_certfail_cb,
-        _connection_handler,
-        conn.xmpp_ctx);
-#else
+    xmpp_conn_set_certfail_handler(conn.xmpp_conn, _connection_certfail_cb);
+
+    return TRUE;
+}
+
+jabber_conn_status_t
+connection_connect(const char* const jid, const char* const passwd, const char* const altdomain, int port,
+                   const char* const tls_policy, const char* const auth_policy)
+{
+    assert(jid != NULL);
+    assert(passwd != NULL);
+    log_info("Connecting as %s", jid);
+
+    _conn_apply_settings(jid, passwd, tls_policy, auth_policy);
+
     int connect_status = xmpp_connect_client(
         conn.xmpp_conn,
         altdomain,
         port,
         _connection_handler,
         conn.xmpp_ctx);
-#endif
 
     if (connect_status == 0) {
         conn.conn_status = JABBER_CONNECTING;
@@ -245,6 +255,263 @@ connection_connect(const char* const jid, const char* const passwd, const char*
     return conn.conn_status;
 }
 
+static int
+iq_reg2_cb(xmpp_conn_t* xmpp_conn, xmpp_stanza_t* stanza, void* userdata)
+{
+    const char* type;
+
+    (void)userdata;
+
+    type = xmpp_stanza_get_type(stanza);
+    if (!type || strcmp(type, "error") == 0) {
+        char* error_message = stanza_get_error_message(stanza);
+        cons_show_error("Server error: %s", error_message);
+        log_debug("Registration error: %s", error_message);
+        goto quit;
+    }
+
+    if (strcmp(type, "result") != 0) {
+        log_debug("Expected type 'result', but got %s.", type);
+        goto quit;
+    }
+
+    cons_show("Registration successful.");
+    log_info("Registration successful.");
+    goto quit;
+
+quit:
+    xmpp_disconnect(xmpp_conn);
+
+    return 0;
+}
+
+static int
+iq_reg_cb(xmpp_conn_t* xmpp_conn, xmpp_stanza_t* stanza, void* userdata)
+{
+    prof_reg_t* reg = (prof_reg_t*)userdata;
+    xmpp_stanza_t* registered = NULL;
+    xmpp_stanza_t* query;
+    const char* type;
+
+    type = xmpp_stanza_get_type(stanza);
+    if (!type || strcmp(type, "error") == 0) {
+        char* error_message = stanza_get_error_message(stanza);
+        cons_show_error("Server error: %s", error_message);
+        log_debug("Registration error: %s", error_message);
+        xmpp_disconnect(xmpp_conn);
+        goto quit;
+    }
+
+    if (strcmp(type, "result") != 0) {
+        log_debug("Expected type 'result', but got %s.", type);
+        xmpp_disconnect(xmpp_conn);
+        goto quit;
+    }
+
+    query = xmpp_stanza_get_child_by_name(stanza, "query");
+    if (query)
+        registered = xmpp_stanza_get_child_by_name(query, "registered");
+    if (registered != NULL) {
+        cons_show_error("Already registered.");
+        log_debug("Already registered.");
+        xmpp_disconnect(xmpp_conn);
+        goto quit;
+    }
+    xmpp_stanza_t* iq = stanza_register_new_account(conn.xmpp_ctx, reg->username, reg->password);
+    xmpp_id_handler_add(xmpp_conn, iq_reg2_cb, xmpp_stanza_get_id(iq), reg);
+    xmpp_send(xmpp_conn, iq);
+
+quit:
+    return 0;
+}
+
+static int
+_register_handle_error(xmpp_conn_t* xmpp_conn, xmpp_stanza_t* stanza, void* userdata)
+{
+    (void)stanza;
+    (void)userdata;
+
+    char* error_message = stanza_get_error_message(stanza);
+    cons_show_error("Server error: %s", error_message);
+    log_debug("Registration error: %s", error_message);
+    xmpp_disconnect(xmpp_conn);
+
+    return 0;
+}
+
+static int
+_register_handle_proceedtls_default(xmpp_conn_t* xmpp_conn,
+                                    xmpp_stanza_t* stanza,
+                                    void* userdata)
+{
+    const char* name = xmpp_stanza_get_name(stanza);
+
+    (void)userdata;
+
+    if (strcmp(name, "proceed") == 0) {
+        log_debug("Proceeding with TLS.");
+        if (xmpp_conn_tls_start(xmpp_conn) == 0) {
+            xmpp_handler_delete(xmpp_conn, _register_handle_error);
+            xmpp_conn_open_stream_default(xmpp_conn);
+        } else {
+            log_debug("TLS failed.");
+            /* failed tls spoils the connection, so disconnect */
+            xmpp_disconnect(xmpp_conn);
+        }
+    }
+    return 0;
+}
+
+static int
+_register_handle_missing_features(xmpp_conn_t* xmpp_conn, void* userdata)
+{
+    (void)userdata;
+
+    log_debug("Timeout");
+    xmpp_disconnect(xmpp_conn);
+
+    return 0;
+}
+
+static int
+_register_handle_features(xmpp_conn_t* xmpp_conn, xmpp_stanza_t* stanza, void* userdata)
+{
+    prof_reg_t* reg = (prof_reg_t*)userdata;
+    xmpp_ctx_t* ctx = conn.xmpp_ctx;
+    xmpp_stanza_t* child;
+    xmpp_stanza_t* iq;
+    char* domain;
+
+    xmpp_timed_handler_delete(xmpp_conn, _register_handle_missing_features);
+
+    /* secure connection if possible */
+    child = xmpp_stanza_get_child_by_name(stanza, "starttls");
+    if (child && (strcmp(xmpp_stanza_get_ns(child), XMPP_NS_TLS) == 0)) {
+        log_debug("Server supports TLS. Attempting to establish...");
+        child = xmpp_stanza_new(ctx);
+        xmpp_stanza_set_name(child, "starttls");
+        xmpp_stanza_set_ns(child, XMPP_NS_TLS);
+        xmpp_handler_add(xmpp_conn, _register_handle_proceedtls_default, XMPP_NS_TLS, NULL,
+                         NULL, NULL);
+        xmpp_send(xmpp_conn, child);
+        xmpp_stanza_release(child);
+        return 0;
+    }
+
+    /* check whether server supports in-band registration */
+    child = xmpp_stanza_get_child_by_name(stanza, "register");
+    if (!child) {
+        log_debug("Server does not support in-band registration.");
+        cons_show_error("Server does not support in-band registration, aborting.");
+        xmpp_disconnect(xmpp_conn);
+        return 0;
+    }
+
+    log_debug("Server supports in-band registration. Attempting registration.");
+
+    domain = strdup(conn.domain);
+    iq = xmpp_iq_new(ctx, "get", "reg1");
+    xmpp_stanza_set_to(iq, domain);
+    child = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(child, "query");
+    xmpp_stanza_set_ns(child, STANZA_NS_REGISTER);
+    xmpp_stanza_add_child(iq, child);
+
+    xmpp_handler_add(xmpp_conn, iq_reg_cb, STANZA_NS_REGISTER, "iq", NULL, reg);
+    xmpp_send(xmpp_conn, iq);
+
+    xmpp_free(ctx, domain);
+    xmpp_stanza_release(child);
+    xmpp_stanza_release(iq);
+
+    return 0;
+}
+
+static void
+_register_handler(xmpp_conn_t* xmpp_conn,
+                  xmpp_conn_event_t status,
+                  int error,
+                  xmpp_stream_error_t* stream_error,
+                  void* userdata)
+{
+    conn.conn_last_event = status;
+
+    prof_reg_t* reg = (prof_reg_t*)userdata;
+    int secured;
+
+    (void)error;
+    (void)stream_error;
+
+    switch (status) {
+
+    case XMPP_CONN_RAW_CONNECT:
+        log_debug("Raw connection established.");
+        xmpp_conn_open_stream_default(xmpp_conn);
+        conn.conn_status = JABBER_RAW_CONNECTED;
+        break;
+
+    case XMPP_CONN_CONNECT:
+        log_debug("Connected.");
+        secured = xmpp_conn_is_secured(xmpp_conn);
+        conn.conn_status = JABBER_CONNECTED;
+        log_debug("Connection is %s.\n",
+                  secured ? "secured" : "NOT secured");
+
+        Jid* my_jid = jid_create(xmpp_conn_get_jid(xmpp_conn));
+        conn.domain = strdup(my_jid->domainpart);
+        jid_destroy(my_jid);
+
+        xmpp_handler_add(xmpp_conn, _register_handle_error, XMPP_NS_STREAMS, "error", NULL,
+                         NULL);
+        xmpp_handler_add(xmpp_conn, _register_handle_features, XMPP_NS_STREAMS, "features",
+                         NULL, reg);
+        xmpp_timed_handler_add(xmpp_conn, _register_handle_missing_features, 5000,
+                               NULL);
+        break;
+
+    case XMPP_CONN_DISCONNECT:
+        log_debug("Disconnected");
+        conn.conn_status = JABBER_DISCONNECTED;
+        break;
+
+    default:
+        break;
+    }
+}
+
+jabber_conn_status_t
+connection_register(const char* const altdomain, int port, const char* const tls_policy,
+                    const char* const username, const char* const password)
+{
+    _conn_apply_settings(altdomain, NULL, tls_policy, NULL);
+
+    prof_reg_t* reg;
+
+    reg = calloc(1, sizeof(*reg));
+    if (reg == NULL) {
+        log_warning("Failed to allocate registration data struct during connect");
+        return JABBER_DISCONNECTED;
+    }
+
+    reg->username = strdup(username);
+    reg->password = strdup(password);
+
+    int connect_status = xmpp_connect_raw(
+        conn.xmpp_conn,
+        altdomain,
+        port,
+        _register_handler,
+        reg);
+
+    if (connect_status == 0) {
+        conn.conn_status = JABBER_RAW_CONNECTING;
+    } else {
+        conn.conn_status = JABBER_DISCONNECTED;
+    }
+
+    return conn.conn_status;
+}
+
 void
 connection_disconnect(void)
 {
@@ -265,12 +532,7 @@ connection_disconnect(void)
     if (!conn.xmpp_in_event_loop) {
         if (conn.xmpp_conn) {
             xmpp_conn_release(conn.xmpp_conn);
-            conn.xmpp_conn = NULL;
-        }
-
-        if (conn.xmpp_ctx) {
-            xmpp_ctx_free(conn.xmpp_ctx);
-            conn.xmpp_ctx = NULL;
+            conn.xmpp_conn = xmpp_conn_new(conn.xmpp_ctx);
         }
     }
 
@@ -303,17 +565,15 @@ connection_clear_data(void)
     }
 }
 
-#ifdef HAVE_LIBMESODE
 TLSCertificate*
 connection_get_tls_peer_cert(void)
 {
-    xmpp_tlscert_t* xmpptlscert = xmpp_conn_tls_peer_cert(conn.xmpp_conn);
+    xmpp_tlscert_t* xmpptlscert = xmpp_conn_get_peer_cert(conn.xmpp_conn);
     TLSCertificate* cert = _xmppcert_to_profcert(xmpptlscert);
-    xmpp_conn_free_tlscert(conn.xmpp_ctx, xmpptlscert);
+    xmpp_tlscert_free(xmpptlscert);
 
     return cert;
 }
-#endif
 
 gboolean
 connection_is_secured(void)
@@ -430,6 +690,8 @@ connection_get_ctx(void)
 const char*
 connection_get_fulljid(void)
 {
+    if (!conn.xmpp_conn)
+        return NULL;
     const char* jid = xmpp_conn_get_bound_jid(conn.xmpp_conn);
     if (jid) {
         return jid;
@@ -442,10 +704,11 @@ char*
 connection_get_barejid(void)
 {
     const char* jid = connection_get_fulljid();
-    char* result;
+    if (!jid)
+        return NULL;
 
     Jid* jidp = jid_create(jid);
-    result = strdup(jidp->barejid);
+    char* result = strdup(jidp->barejid);
     jid_destroy(jidp);
 
     return result;
@@ -455,8 +718,9 @@ char*
 connection_get_user(void)
 {
     const char* jid = connection_get_fulljid();
-    char* result;
-    result = strdup(jid);
+    if (!jid)
+        return NULL;
+    char* result = strdup(jid);
 
     char* split = strchr(result, '@');
     *split = '\0';
@@ -515,14 +779,13 @@ char*
 connection_create_stanza_id(void)
 {
     char* rndid = get_random_string(CON_RAND_ID_LEN);
-
     assert(rndid != NULL);
 
     gchar* hmac = g_compute_hmac_for_string(G_CHECKSUM_SHA1,
                                             (guchar*)prof_identifier, strlen(prof_identifier),
                                             rndid, strlen(rndid));
 
-    char *ret = g_strdup_printf("%s%s", rndid, hmac);
+    char* ret = g_strdup_printf("%s%s", rndid, hmac);
 
     free(rndid);
     g_free(hmac);
@@ -557,6 +820,119 @@ connection_set_priority(const int priority)
     conn.priority = priority;
 }
 
+#if defined(LIBXMPP_VERSION_MAJOR) && defined(LIBXMPP_VERSION_MINOR) \
+    && ((LIBXMPP_VERSION_MAJOR > 0) || (LIBXMPP_VERSION_MINOR >= 12))
+static xmpp_stanza_t*
+_get_soh_error(xmpp_stanza_t* error_stanza)
+{
+    return xmpp_stanza_get_child_by_path(error_stanza,
+                                         XMPP_STANZA_NAME_IN_NS("error", STANZA_NS_STREAMS),
+                                         XMPP_STANZA_NAME_IN_NS("see-other-host", STANZA_NS_XMPP_STREAMS),
+                                         NULL);
+}
+#else
+static xmpp_stanza_t*
+_get_soh_error(xmpp_stanza_t* error_stanza)
+{
+    const char* name = xmpp_stanza_get_name(error_stanza);
+    const char* ns = xmpp_stanza_get_ns(error_stanza);
+    if (!name || !ns || strcmp(name, "error") || strcmp(ns, STANZA_NS_STREAMS)) {
+        log_debug("_get_soh_error: could not find error stanza");
+        return NULL;
+    }
+    return xmpp_stanza_get_child_by_name_and_ns(error_stanza, "see-other-host", STANZA_NS_XMPP_STREAMS);
+}
+#endif
+
+#if GLIB_CHECK_VERSION(2, 66, 0)
+static gboolean
+_split_url(const char* alturi, gchar** host, gint* port)
+{
+    /* Construct a valid URI with `schema://` as `g_uri_split_network()`
+     * requires this to be there.
+     */
+    const char* xmpp = "xmpp://";
+    char* xmpp_uri = _xmalloc(strlen(xmpp) + strlen(alturi) + 1, NULL);
+    memcpy(xmpp_uri, xmpp, strlen(xmpp));
+    memcpy(xmpp_uri + strlen(xmpp), alturi, strlen(alturi) + 1);
+    gboolean ret = g_uri_split_network(xmpp_uri, 0, NULL, host, port, NULL);
+    free(xmpp_uri);
+    /* fix-up `port` as g_uri_split_network() sets port to `-1` if it's missing
+     * in the passed-in URI, but libstrophe expects a "missing port"
+     * to be passed as `0` (which then results in connecting to the standard port).
+     */
+    if (*port == -1)
+        *port = 0;
+    return ret;
+}
+#else
+/* poor-mans URL splitting */
+static gboolean
+_split_url(const char* alturi, gchar** host, gint* port)
+{
+    ptrdiff_t hostlen;
+    /* search ':' from start and end
+     * if `first` matches `last` it's a `hostname:port` combination
+     * if `first` is different than `last` it's `[ip:v6]` or `[ip:v6]:port`
+     */
+    char* first = strchr(alturi, ':');
+    char* last = strrchr(alturi, ':');
+    if (first) {
+        if (first == last) {
+            hostlen = last - alturi + 1;
+            if (!strtoi_range(last + 1, port, 1, 65535, NULL))
+                return FALSE;
+        } else {
+            /* IPv6 handling */
+            char* bracket = strrchr(alturi, ']');
+            if (!bracket)
+                return FALSE;
+            if (bracket > last) {
+                /* `[ip:v6]` */
+                hostlen = strlen(alturi) + 1;
+                *port = 0;
+            } else {
+                /* `[ip:v6]:port` */
+                hostlen = last - alturi + 1;
+                if (!strtoi_range(last + 1, port, 1, 65535, NULL))
+                    return FALSE;
+            }
+        }
+    } else {
+        hostlen = strlen(alturi) + 1;
+        *port = 0;
+    }
+    gchar* buf = g_malloc(hostlen);
+    if (!buf)
+        return FALSE;
+    memcpy(buf, alturi, hostlen);
+    buf[hostlen - 1] = '\0';
+    *host = buf;
+    return TRUE;
+}
+#endif
+
+static bool
+_get_other_host(xmpp_stanza_t* error_stanza, gchar** host, int* port)
+{
+    xmpp_stanza_t* soh_error = _get_soh_error(error_stanza);
+    if (!soh_error || !xmpp_stanza_get_children(soh_error)) {
+        log_debug("_get_other_host: stream-error contains no see-other-host");
+        return false;
+    }
+    const char* alturi = xmpp_stanza_get_text_ptr(xmpp_stanza_get_children(soh_error));
+    if (!alturi) {
+        log_debug("_get_other_host: see-other-host contains no text");
+        return false;
+    }
+
+    if (!_split_url(alturi, host, port)) {
+        log_debug("_get_other_host: Could not split \"%s\"", alturi);
+        return false;
+    }
+    return true;
+}
+
 static void
 _connection_handler(xmpp_conn_t* const xmpp_conn, const xmpp_conn_event_t status, const int error,
                     xmpp_stream_error_t* const stream_error, void* const userdata)
@@ -581,6 +957,23 @@ _connection_handler(xmpp_conn_t* const xmpp_conn, const xmpp_conn_event_t status
 
         break;
 
+    // raw connection success
+    case XMPP_CONN_RAW_CONNECT:
+        log_debug("Connection handler: XMPP_CONN_RAW_CONNECT");
+        conn.conn_status = JABBER_RAW_CONNECTED;
+
+        Jid* my_raw_jid = jid_create(xmpp_conn_get_jid(conn.xmpp_conn));
+        log_debug("jid: %s", xmpp_conn_get_jid(conn.xmpp_conn));
+        conn.domain = strdup(my_raw_jid->domainpart);
+        jid_destroy(my_raw_jid);
+
+        conn.features_by_jid = g_hash_table_new_full(g_str_hash, g_str_equal, free, (GDestroyNotify)g_hash_table_destroy);
+        g_hash_table_insert(conn.features_by_jid, strdup(conn.domain), g_hash_table_new_full(g_str_hash, g_str_equal, free, NULL));
+
+        xmpp_conn_open_stream_default(xmpp_conn);
+
+        break;
+
     // disconnected
     case XMPP_CONN_DISCONNECT:
         log_debug("Connection handler: XMPP_CONN_DISCONNECT");
@@ -592,6 +985,14 @@ _connection_handler(xmpp_conn_t* const xmpp_conn, const xmpp_conn_event_t status
 
             // login attempt failed
         } else if (conn.conn_status != JABBER_DISCONNECTING) {
+            gchar* host;
+            int port;
+            if (stream_error && stream_error->stanza && _get_other_host(stream_error->stanza, &host, &port)) {
+                session_reconnect(host, port);
+                log_debug("Connection handler: Forcing a re-connect to \"%s\"", host);
+                conn.conn_status = JABBER_RECONNECT;
+                return;
+            }
             log_debug("Connection handler: Login failed");
             session_login_failed();
         }
@@ -613,9 +1014,8 @@ _connection_handler(xmpp_conn_t* const xmpp_conn, const xmpp_conn_event_t status
     }
 }
 
-#ifdef HAVE_LIBMESODE
 static int
-_connection_certfail_cb(xmpp_tlscert_t* xmpptlscert, const char* const errormsg)
+_connection_certfail_cb(const xmpp_tlscert_t* xmpptlscert, const char* errormsg)
 {
     TLSCertificate* cert = _xmppcert_to_profcert(xmpptlscert);
 
@@ -626,47 +1026,21 @@ _connection_certfail_cb(xmpp_tlscert_t* xmpptlscert, const char* const errormsg)
 }
 
 TLSCertificate*
-_xmppcert_to_profcert(xmpp_tlscert_t* xmpptlscert)
+_xmppcert_to_profcert(const xmpp_tlscert_t* xmpptlscert)
 {
+    int version = (int)strtol(
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_VERSION), NULL, 10);
     return tlscerts_new(
-        xmpp_conn_tlscert_fingerprint(xmpptlscert),
-        xmpp_conn_tlscert_version(xmpptlscert),
-        xmpp_conn_tlscert_serialnumber(xmpptlscert),
-        xmpp_conn_tlscert_subjectname(xmpptlscert),
-        xmpp_conn_tlscert_issuername(xmpptlscert),
-        xmpp_conn_tlscert_notbefore(xmpptlscert),
-        xmpp_conn_tlscert_notafter(xmpptlscert),
-        xmpp_conn_tlscert_key_algorithm(xmpptlscert),
-        xmpp_conn_tlscert_signature_algorithm(xmpptlscert));
-}
-#endif
-
-static xmpp_log_t*
-_xmpp_get_file_logger(void)
-{
-    log_level_t prof_level = log_get_filter();
-    xmpp_log_level_t xmpp_level = XMPP_LEVEL_ERROR;
-
-    switch (prof_level) {
-    case PROF_LEVEL_DEBUG:
-        xmpp_level = XMPP_LEVEL_DEBUG;
-        break;
-    case PROF_LEVEL_INFO:
-        xmpp_level = XMPP_LEVEL_INFO;
-        break;
-    case PROF_LEVEL_WARN:
-        xmpp_level = XMPP_LEVEL_WARN;
-        break;
-    default:
-        xmpp_level = XMPP_LEVEL_ERROR;
-        break;
-    }
-
-    xmpp_log_t* file_log = malloc(sizeof(xmpp_log_t));
-    file_log->handler = _xmpp_file_logger;
-    file_log->userdata = &xmpp_level;
-
-    return file_log;
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_FINGERPRINT_SHA1),
+        version,
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_SERIALNUMBER),
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_SUBJECT),
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_ISSUER),
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_NOTBEFORE),
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_NOTAFTER),
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_KEYALG),
+        xmpp_tlscert_get_string(xmpptlscert, XMPP_CERT_SIGALG),
+        xmpp_tlscert_get_pem(xmpptlscert));
 }
 
 static void
@@ -742,12 +1116,12 @@ _random_bytes_close(void)
 static void
 _compute_identifier(const char* barejid)
 {
-    //in case of reconnect (lost connection)
+    // in case of reconnect (lost connection)
     free(prof_identifier);
 
     prof_identifier = g_compute_hmac_for_string(G_CHECKSUM_SHA256,
-                                            (guchar*)profanity_instance_id, strlen(profanity_instance_id),
-                                            barejid, strlen(barejid));
+                                                (guchar*)profanity_instance_id, strlen(profanity_instance_id),
+                                                barejid, strlen(barejid));
 }
 
 const char*
