@@ -44,13 +44,7 @@
 #include <stdio.h>
 #include <glib.h>
 
-#ifdef HAVE_LIBMESODE
-#include <mesode.h>
-#endif
-
-#ifdef HAVE_LIBSTROPHE
 #include <strophe.h>
-#endif
 
 #include "profanity.h"
 #include "log.h"
@@ -2343,7 +2337,7 @@ _disco_info_response_id_handler(xmpp_stanza_t* const stanza, void* const userdat
                     }
                 }
             } else if (g_strcmp0(child_type, STANZA_TYPE_RESULT) == 0) {
-                GHashTable *adr = stanza_get_service_contact_addresses(connection_get_ctx(), child);
+                GHashTable* adr = stanza_get_service_contact_addresses(connection_get_ctx(), child);
                 cons_show_disco_contact_information(adr);
                 g_hash_table_destroy(adr);
             }
@@ -2456,14 +2450,11 @@ _http_upload_response_id_handler(xmpp_stanza_t* const stanza, void* const userda
                     const char* header_name = xmpp_stanza_get_attribute(header, STANZA_ATTR_NAME);
                     if (g_strcmp0(header_name, STANZA_HEADER_AUTHORIZATION) == 0) {
                         upload->authorization = xmpp_stanza_get_text(header);
-                    }
-                    else if (g_strcmp0(header_name, STANZA_HEADER_COOKIE) == 0) {
+                    } else if (g_strcmp0(header_name, STANZA_HEADER_COOKIE) == 0) {
                         upload->cookie = xmpp_stanza_get_text(header);
-                    }
-                    else if (g_strcmp0(header_name, STANZA_HEADER_EXPIRES) == 0) {
+                    } else if (g_strcmp0(header_name, STANZA_HEADER_EXPIRES) == 0) {
                         upload->expires = xmpp_stanza_get_text(header);
-                    }
-                    else {
+                    } else {
                         log_warning("[HTTP upload] unknown header: %s", header_name);
                     }
                 }
@@ -2629,8 +2620,8 @@ _mam_rsm_id_handler(xmpp_stanza_t* const stanza, void* const userdata)
         if (fin) {
             xmpp_stanza_t* set = xmpp_stanza_get_child_by_name_and_ns(fin, STANZA_TYPE_SET, STANZA_NS_RSM);
             if (set) {
-                char *lastid = NULL;
-                xmpp_stanza_t* last =  xmpp_stanza_get_child_by_name(set, STANZA_NAME_LAST);
+                char* lastid = NULL;
+                xmpp_stanza_t* last = xmpp_stanza_get_child_by_name(set, STANZA_NAME_LAST);
                 if (last) {
                     lastid = xmpp_stanza_get_text(last);
                 }
@@ -2807,3 +2798,56 @@ iq_muc_register_nick(const char* const roomjid)
     xmpp_stanza_release(iq);
     xmpp_stanza_release(query);
 }
+
+void
+publish_user_mood(const char* const mood, const char* const text)
+{
+    xmpp_ctx_t* const ctx = connection_get_ctx();
+    char* id = connection_create_stanza_id();
+
+    xmpp_stanza_t* iq = xmpp_iq_new(ctx, STANZA_TYPE_SET, id);
+
+    xmpp_stanza_t* pubsub = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(pubsub, STANZA_NAME_PUBSUB);
+    xmpp_stanza_set_ns(pubsub, STANZA_NS_PUBSUB);
+    xmpp_stanza_add_child(iq, pubsub);
+
+    xmpp_stanza_t* publish = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(publish, STANZA_NAME_PUBLISH);
+    xmpp_stanza_set_attribute(publish, STANZA_ATTR_NODE, STANZA_NS_MOOD);
+    xmpp_stanza_add_child(pubsub, publish);
+
+    xmpp_stanza_t* item = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(item, STANZA_NAME_ITEM);
+    xmpp_stanza_set_attribute(item, "id", "current");
+    xmpp_stanza_add_child(publish, item);
+
+    xmpp_stanza_t* mood_t = xmpp_stanza_new(ctx);
+    xmpp_stanza_set_name(mood_t, STANZA_NAME_MOOD);
+    xmpp_stanza_set_ns(mood_t, STANZA_NS_MOOD);
+    xmpp_stanza_add_child(item, mood_t);
+
+    xmpp_stanza_t* x = xmpp_stanza_new(ctx);
+    xmpp_stanza_t* text_t = xmpp_stanza_new(ctx);
+    xmpp_stanza_t* t = xmpp_stanza_new(ctx);
+    if (mood) {
+        xmpp_stanza_set_name(x, mood);
+        xmpp_stanza_add_child(mood_t, x);
+
+        xmpp_stanza_set_name(text_t, STANZA_NAME_TEXT);
+        xmpp_stanza_add_child(mood_t, text_t);
+
+        xmpp_stanza_set_text(t, text);
+        xmpp_stanza_add_child(text_t, t);
+    }
+    iq_send_stanza(iq);
+
+    xmpp_stanza_release(iq);
+    xmpp_stanza_release(pubsub);
+    xmpp_stanza_release(publish);
+    xmpp_stanza_release(item);
+    xmpp_stanza_release(mood_t);
+    xmpp_stanza_release(x);
+    xmpp_stanza_release(text_t);
+    xmpp_stanza_release(t);
+}
