@@ -38,13 +38,7 @@
 
 #include "config.h"
 
-#ifdef HAVE_LIBMESODE
-#include <mesode.h>
-#endif
-
-#ifdef HAVE_LIBSTROPHE
 #include <strophe.h>
-#endif
 
 #include <xmpp/xmpp.h>
 
@@ -123,6 +117,10 @@
 #define STANZA_NAME_USERNAME         "username"
 #define STANZA_NAME_PROPOSE          "propose"
 #define STANZA_NAME_REPORT           "report"
+#define STANZA_NAME_EVENT            "event"
+#define STANZA_NAME_MOOD             "mood"
+#define STANZA_NAME_RECEIVED         "received"
+#define STANZA_NAME_SENT             "sent"
 
 // error conditions
 #define STANZA_NAME_BAD_REQUEST             "bad-request"
@@ -245,6 +243,10 @@
 #define STANZA_NS_JINGLE_MESSAGE          "urn:xmpp:jingle-message:0"
 #define STANZA_NS_JINGLE_RTP              "urn:xmpp:jingle:apps:rtp:1"
 #define STANZA_NS_REPORTING               "urn:xmpp:reporting:1"
+#define STANZA_NS_MOOD                    "http://jabber.org/protocol/mood"
+#define STANZA_NS_MOOD_NOTIFY             "http://jabber.org/protocol/mood+notify"
+#define STANZA_NS_STREAMS                 "http://etherx.jabber.org/streams"
+#define STANZA_NS_XMPP_STREAMS            "urn:ietf:params:xml:ns:xmpp-streams"
 
 #define STANZA_DATAFORM_SOFTWARE "urn:xmpp:dataforms:softwareinfo"
 
@@ -409,6 +411,7 @@ void stanza_free_caps(XMPPCaps* caps);
 xmpp_stanza_t* stanza_create_avatar_retrieve_data_request(xmpp_ctx_t* ctx, const char* stanza_id, const char* const item_id, const char* const jid);
 xmpp_stanza_t* stanza_create_mam_iq(xmpp_ctx_t* ctx, const char* const jid, const char* const startdate, const char* const lastid);
 xmpp_stanza_t* stanza_change_password(xmpp_ctx_t* ctx, const char* const user, const char* const password);
+xmpp_stanza_t* stanza_register_new_account(xmpp_ctx_t* ctx, const char* const user, const char* const password);
 xmpp_stanza_t* stanza_request_voice(xmpp_ctx_t* ctx, const char* const room);
 xmpp_stanza_t* stanza_create_approve_voice(xmpp_ctx_t* ctx, const char* const id, const char* const jid, const char* const node, DataForm* form);
 xmpp_stanza_t* stanza_create_muc_register_nick(xmpp_ctx_t* ctx, const char* const id, const char* const jid, const char* const node, DataForm* form);
