@@ -40,13 +40,7 @@
 
 #include "config.h"
 
-#ifdef HAVE_LIBMESODE
-#include <mesode.h>
-#endif
-
-#ifdef HAVE_LIBSTROPHE
 #include <strophe.h>
-#endif
 
 #include "config/accounts.h"
 #include "config/tlscerts.h"
@@ -76,7 +70,10 @@ typedef enum {
     JABBER_CONNECTING,
     JABBER_CONNECTED,
     JABBER_DISCONNECTING,
-    JABBER_DISCONNECTED
+    JABBER_DISCONNECTED,
+    JABBER_RAW_CONNECTING,
+    JABBER_RAW_CONNECTED,
+    JABBER_RECONNECT
 } jabber_conn_status_t;
 
 typedef enum {
@@ -103,7 +100,7 @@ typedef struct bookmark_t
     char* password;
     char* name;
     gboolean autojoin;
-    int ext_gajim_minimize; //0 - non existent, 1 - true, 2 - false
+    int ext_gajim_minimize; // 0 - non existent, 1 - true, 2 - false
 } Bookmark;
 
 typedef struct disco_identity_t
@@ -165,7 +162,7 @@ typedef struct prof_message_t
     /* stanza-id from XEP 0359. Used for MAM. archive_id in our database (see database.c)
      * coming in as <stanza-id> for live messages
      * coming in as <result id=""> for MAM messages*/
-    char *stanzaid;
+    char* stanzaid;
     /* The raw body from xmpp message, either plaintext or OTR encrypted text */
     char* body;
     /* The encrypted message as for PGP */
@@ -183,6 +180,7 @@ void session_init(void);
 jabber_conn_status_t session_connect_with_details(const char* const jid, const char* const passwd,
                                                   const char* const altdomain, const int port, const char* const tls_policy, const char* const auth_policy);
 jabber_conn_status_t session_connect_with_account(const ProfAccount* const account);
+
 void session_disconnect(void);
 void session_shutdown(void);
 void session_process_events(void);
@@ -196,9 +194,7 @@ char* connection_get_barejid(void);
 char* connection_get_user(void);
 char* connection_create_uuid(void);
 void connection_free_uuid(char* uuid);
-#ifdef HAVE_LIBMESODE
 TLSCertificate* connection_get_tls_peer_cert(void);
-#endif
 gboolean connection_is_secured(void);
 gboolean connection_send_stanza(const char* const stanza);
 GList* connection_get_available_resources(void);
@@ -312,4 +308,6 @@ FormField* form_get_field_by_tag(DataForm* form, const char* const tag);
 Autocomplete form_get_value_ac(DataForm* form, const char* const tag);
 void form_reset_autocompleters(DataForm* form);
 
+void publish_user_mood(const char* const mood, const char* const text);
+
 #endif
