@@ -211,18 +211,21 @@ ui_win_unread(int index)
 }
 
 gboolean
-ui_win_has_attention(int index) {
-	return FALSE;
+ui_win_has_attention(int index)
+{
+    return FALSE;
 }
 
 gboolean
-win_has_attention(ProfWin* window){
-	return FALSE;
+win_has_attention(ProfWin* window)
+{
+    return FALSE;
 }
 
 gboolean
-win_toggle_attention(ProfWin* window){
-	return FALSE;
+win_toggle_attention(ProfWin* window)
+{
+    return FALSE;
 }
 char*
 ui_ask_password(gboolean confirm)
@@ -646,11 +649,11 @@ jabber_get_tls_peer_cert(void)
     return NULL;
 }
 void
-cons_show_tlscert(TLSCertificate* cert)
+cons_show_tlscert(const TLSCertificate* cert)
 {
 }
 void
-cons_show_tlscert_summary(TLSCertificate* cert)
+cons_show_tlscert_summary(const TLSCertificate* cert)
 {
 }
 
@@ -843,7 +846,7 @@ cons_show_wins(gboolean unread)
 {
 }
 
-void 
+void
 cons_show_wins_attention()
 {
 }
@@ -1304,6 +1307,11 @@ win_get_title(ProfWin* window)
 {
     return NULL;
 }
+char*
+win_get_last_sent_message(ProfWin* window)
+{
+    return NULL;
+}
 void
 win_show_occupant(ProfWin* window, Occupant* occupant)
 {
